package data

import (
	"context"
	"git.oa00.com/supply-chain/service/client"
	"git.oa00.com/supply-chain/service/lib/bean"
	"github.com/shopspring/decimal"
)

type order struct {
}

type ArgsPayOrderLists struct {
	StartLadingBillAt string
	EndLadingBillAt   string
	Page              bean.Page
}

type ReplyPayOrderLists struct {
	Lists []PayOrderItem `json:"lists"`
	Total int64          `json:"total"`
}

type PayOrderItem struct {
	SourceName         string          `json:"sourceName"`         // 供应渠道
	SourceSonName      string          `json:"sourceSonName"`      // 供应商
	CustomerName       string          `json:"customerName"`       // 客户名
	OrderSn            string          `json:"orderSn"`            // 原始订单号
	OrderSubSn         string          `json:"orderSubSn"`         // 订单号
	SupplierOrderSn    string          `json:"supplierOrderSn"`    // 供应商订单号
	OrderStatus        uint            `json:"orderStatus"`        // 订单状态
	LadingBillAt       int64           `json:"ladingBillAt"`       // 支付时间
	StockOutAt         int64           `json:"stockOutAt"`         // 发货时间
	FinishAt           int64           `json:"finishAt"`           // 确认收货时间
	SkuName            string          `json:"skuName"`            // 商品名称
	SkuUpcCode         string          `json:"skuUpcCode"`         // 商品条码
	Specification      string          `json:"specification"`      // 规格
	Quality            uint            `json:"quality"`            // 数量
	ProduceSupplyPrice decimal.Decimal `json:"produceSupplyPrice"` // 采购单价
	ProduceTotalPrice  decimal.Decimal `json:"produceTotalPrice"`  // 采购总金额
	ProduceFreightFee  decimal.Decimal `json:"ProduceFreightFee"`  // 采购应付运费
	ProducePrice       decimal.Decimal `json:"producePrice"`       // 采购合计金额
	SaleSupplyPrice    decimal.Decimal `json:"saleSupplyPrice"`    // 销售单价
	SaleTotalPrice     decimal.Decimal `json:"saleTotalPrice"`     // 销售总金额
	SaleFreightFee     decimal.Decimal `json:"saleFreightFee"`     // 销售应收运费
	SalePrice          decimal.Decimal `json:"salePrice"`          // 销售合计金额
	Unit               string          `json:"unit"`               // 单位
	Tax                string          `json:"tax"`                // 税率
	ReceiverName       string          `json:"receiverName"`       // 收件人
	ReceiverPhone      string          `json:"receiverPhone"`      // 收件人手机号
	ReceiverAddress    string          `json:"receiverAddress"`    // 收件人地址
}

// PayOrderList @Title 支付订单统计
func (o *order) PayOrderList(ctx context.Context, args ArgsPayOrderLists) (result ReplyPayOrderLists, err error) {
	xClient, err := client.GetClient(o)
	if err != nil {
		return
	}
	err = xClient.Call(ctx, "PayOrderList", args, &result)
	return
}

type ArgsCancelOrderLists struct {
	StartCancelAt string
	EndCancelAt   string
	Page          bean.Page
}

type ReplyCancelOrderLists struct {
	Lists []CancelOrderItem `json:"lists"`
	Total int64             `json:"total"`
}
type CancelOrderItem struct {
	SourceName      string `json:"sourceName"`      // 供应渠道
	SourceSonName   string `json:"sourceSonName"`   // 供应商
	CustomerName    string `json:"customerName"`    // 客户名
	OrderSn         string `json:"orderSn"`         // 原始订单号
	OrderSubSn      string `json:"orderSubSn"`      // 订单号
	SupplierOrderSn string `json:"supplierOrderSn"` // 供应商订单号
	OrderStatus     uint   `json:"orderStatus"`     // 订单状态
	LadingBillAt    int64  `json:"ladingBillAt"`    // 支付时间
	StockOutAt      int64  `json:"stockOutAt"`      // 发货时间
	CancelAt        int64  `json:"cancelAt"`        // 取消时间

	TotalPrice  decimal.Decimal `json:"totalPrice"`  // 商品金额
	FreightFee  decimal.Decimal `json:"freightFee"`  // 运费
	Price       decimal.Decimal `json:"price"`       // 销售合计金额
	RefundPrice decimal.Decimal `json:"refundPrice"` // 退款金额
}

// CancelOrderLists @Title 取消订单统计
func (o *order) CancelOrderLists(ctx context.Context, args ArgsCancelOrderLists) (result ReplyCancelOrderLists, err error) {
	xClient, err := client.GetClient(o)
	if err != nil {
		return
	}
	err = xClient.Call(ctx, "CancelOrderLists", args, &result)
	return
}

type ArgsStockOutOrderList struct {
	StartStockOutAt string
	EndStockOutAt   string
	Page            bean.Page
}

type ReplyStockOutOrderList struct {
	Lists []StockOutOrderItem `json:"lists"`
	Total int64               `json:"total"`
}

type StockOutOrderItem struct {
	SourceName         string          `json:"sourceName"`         // 供应渠道
	SourceSonName      string          `json:"sourceSonName"`      // 供应商
	CustomerName       string          `json:"customerName"`       // 客户名
	OrderSn            string          `json:"orderSn"`            // 原始订单号
	OrderSubSn         string          `json:"orderSubSn"`         // 订单号
	SupplierOrderSn    string          `json:"supplierOrderSn"`    // 供应商订单号
	OrderStatus        uint            `json:"orderStatus"`        // 订单状态
	LadingBillAt       int64           `json:"ladingBillAt"`       // 支付时间
	StockOutAt         int64           `json:"stockOutAt"`         // 发货时间
	FinishAt           int64           `json:"finishAt"`           // 确认收货时间
	SkuName            string          `json:"skuName"`            // 商品名称
	SkuUpcCode         string          `json:"skuUpcCode"`         // 商品条码
	Specification      string          `json:"specification"`      // 规格
	Quality            uint            `json:"quality"`            // 数量
	ProduceSupplyPrice decimal.Decimal `json:"produceSupplyPrice"` // 采购单价
	ProduceTotalPrice  decimal.Decimal `json:"produceTotalPrice"`  // 采购总金额
	ProduceFreightFee  decimal.Decimal `json:"ProduceFreightFee"`  // 采购应付运费
	ProducePrice       decimal.Decimal `json:"producePrice"`       // 采购合计金额
	SaleSupplyPrice    decimal.Decimal `json:"saleSupplyPrice"`    // 销售单价
	SaleTotalPrice     decimal.Decimal `json:"saleTotalPrice"`     // 销售总金额
	SaleFreightFee     decimal.Decimal `json:"saleFreightFee"`     // 销售应收运费
	SalePrice          decimal.Decimal `json:"salePrice"`          // 销售合计金额
	Unit               string          `json:"unit"`               // 单位
	Tax                string          `json:"tax"`                // 税率
	ReceiverName       string          `json:"receiverName"`       // 收件人
	ReceiverPhone      string          `json:"receiverPhone"`      // 收件人手机号
	ReceiverAddress    string          `json:"receiverAddress"`    // 收件人地址
}

// StockOutOrderList @Title 发货订单统计
func (o *order) StockOutOrderList(ctx context.Context, args ArgsStockOutOrderList) (result ReplyStockOutOrderList, err error) {
	xClient, err := client.GetClient(o)
	if err != nil {
		return
	}
	err = xClient.Call(ctx, "StockOutOrderList", args, &result)
	return
}
